==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/StepFunctions/DescribeStateMachine.pm <==

package Paws::StepFunctions::DescribeStateMachine;
  use Moose;
  has StateMachineArn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'stateMachineArn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeStateMachine');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::StepFunctions::DescribeStateMachineOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::StepFunctions::DescribeStateMachine - Arguments for method DescribeStateMachine on L<Paws::StepFunctions>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeStateMachine on the
L<AWS Step Functions|Paws::StepFunctions> service. Use the attributes of this class
as arguments to method DescribeStateMachine.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeStateMachine.

=head1 SYNOPSIS

    my $states = Paws->service('StepFunctions');
    my $DescribeStateMachineOutput = $states->DescribeStateMachine(
      StateMachineArn => 'MyArn',

    );

    # Results:
    my $CreationDate    = $DescribeStateMachineOutput->CreationDate;
    my $Definition      = $DescribeStateMachineOutput->Definition;
    my $Name            = $DescribeStateMachineOutput->Name;
    my $RoleArn         = $DescribeStateMachineOutput->RoleArn;
    my $StateMachineArn = $DescribeStateMachineOutput->StateMachineArn;
    my $Status          = $DescribeStateMachineOutput->Status;

    # Returns a L<Paws::StepFunctions::DescribeStateMachineOutput> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/states/DescribeStateMachine>

=head1 ATTRIBUTES


=head2 B<REQUIRED> StateMachineArn => Str

The Amazon Resource Name (ARN) of the state machine to describe.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeStateMachine in L<Paws::StepFunctions>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/StepFunctions/DescribeStateMachine.pm <==

package Paws::StepFunctions::DescribeStateMachine;
  use Moose;
  has StateMachineArn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'stateMachineArn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeStateMachine');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::StepFunctions::DescribeStateMachineOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::StepFunctions::DescribeStateMachine - Arguments for method DescribeStateMachine on L<Paws::StepFunctions>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeStateMachine on the
L<AWS Step Functions|Paws::StepFunctions> service. Use the attributes of this class
as arguments to method DescribeStateMachine.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeStateMachine.

=head1 SYNOPSIS

    my $states = Paws->service('StepFunctions');
    my $DescribeStateMachineOutput = $states->DescribeStateMachine(
      StateMachineArn => 'MyArn',

    );

    # Results:
    my $CreationDate = $DescribeStateMachineOutput->CreationDate;
    my $Definition   = $DescribeStateMachineOutput->Definition;
    my $LoggingConfiguration =
      $DescribeStateMachineOutput->LoggingConfiguration;
    my $Name            = $DescribeStateMachineOutput->Name;
    my $RoleArn         = $DescribeStateMachineOutput->RoleArn;
    my $StateMachineArn = $DescribeStateMachineOutput->StateMachineArn;
    my $Status          = $DescribeStateMachineOutput->Status;
    my $Type            = $DescribeStateMachineOutput->Type;

    # Returns a L<Paws::StepFunctions::DescribeStateMachineOutput> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/states/DescribeStateMachine>

=head1 ATTRIBUTES


=head2 B<REQUIRED> StateMachineArn => Str

The Amazon Resource Name (ARN) of the state machine to describe.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeStateMachine in L<Paws::StepFunctions>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
